@@ -26,11 +26,11 @@ import osso
 import xml.etree.ElementTree as ET
 
 a_name = "Quick Clip"
-a_version = "0.4.0"
+a_version = "0.4.2"
 
 history = []
 history_target = []
-osso_context = osso.Context('com.quickclip.Quickclip','.21', False)
+osso_context = osso.Context('com.quickclip.Quickclip','0.4.2', False)
 
 # Main class
 
@@ -436,7 +436,7 @@ Brent Chiodo""")
       response = dialog.run()
 
       if response == 1:
-         subprocess.Popen('/usr/bin/dbus-send --print-reply --dest=com.nokia.osso_browser /com/nokia/osso_browser com.nokia.osso_browser.mime_open string:"http://brentdc.maemobox.org/donate.html"', shell=True)
+         subprocess.Popen('/usr/bin/dbus-send --print-reply --dest=com.nokia.osso_browser /com/nokia/osso_browser com.nokia.osso_browser.mime_open string:"file:///home/user/.quickclip/donate.html"', shell=True)
 
       dialog.destroy()
 
